@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-data-cache-source.c:
  *
@@ -22,7 +21,7 @@
 
 #include <goffice/goffice.h>
 #include <gnumeric-config.h>
-#include "go-data-cache-source.h"
+#include <go-data-cache-source.h>
 
 GType
 go_data_cache_source_get_type (void)
