@@ -111,6 +111,12 @@ sheet_object_set_print_flag (SheetObject *so, gboolean *print)
 		so->flags &= ~SHEET_OBJECT_PRINT;
 }
 
+gboolean
+sheet_object_get_print_flag (SheetObject *so)
+{
+	return (so->flags & SHEET_OBJECT_PRINT) != 0;
+}
+
 
 static void
 cb_so_size_position (SheetObject *so, SheetControl *sc)
@@ -258,7 +264,7 @@ sheet_object_populate_menu_real (SheetObject *so, GPtrArray *actions)
 			{ "edit-copy",		N_("_Copy"),		NULL,  0, cb_so_copy, NULL },
 		};
 		for (i = 0 ; i < G_N_ELEMENTS (so_actions); i++)
-				g_ptr_array_add (actions, (gpointer) (so_actions + i));
+			g_ptr_array_add (actions, (gpointer) (so_actions + i));
 	} else {
 		static SheetObjectAction const so_actions [] = {
 			{ GTK_STOCK_PROPERTIES,	        NULL, NULL,  0, sheet_object_get_editor, sheet_object_can_prop},
@@ -294,7 +300,7 @@ sheet_object_populate_menu_real (SheetObject *so, GPtrArray *actions)
 void
 sheet_object_populate_menu (SheetObject *so, GPtrArray *actions)
 {
-	g_return_if_fail  (NULL != so);
+	g_return_if_fail (NULL != so);
 
 	GNM_SO_CLASS (G_OBJECT_GET_CLASS(so))->populate_menu (so, actions);
 }
@@ -616,7 +622,7 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
  * sheet_object_clear_sheet:
  * @so: #SheetObject
  *
- * Removes @so from its container, unrealizes all views, disconects the
+ * Removes @so from its container, unrealizes all views, disconnects the
  * associated data and unrefs the object
  **/
 void
@@ -1186,7 +1192,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
  * @t: The type of object to lookup, %G_TYPE_NONE for any.
  *
  * Returns: (element-type SheetObject) (transfer container): a list
- * containing all objects of exactly the specified type (inheritence does
+ * containing all objects of exactly the specified type (inheritance does
  * not count) that are completely contained in @r.
  **/
 GSList *
