@@ -49,10 +49,13 @@
 // Sheets user has specified as export options
 #define SSCONVERT_SHEET_SET_KEY "ssconvert-sheets"
 
+#define DEFAULT_IMAGE_FORMAT "svg"
+
 static gboolean ssconvert_show_version = FALSE;
 static gboolean ssconvert_verbose = FALSE;
 static gboolean ssconvert_list_exporters = FALSE;
 static gboolean ssconvert_list_importers = FALSE;
+static gboolean ssconvert_list_image_formats = FALSE;
 static gboolean ssconvert_one_file_per_sheet = FALSE;
 static gboolean ssconvert_object_export = FALSE;
 static GType ssconvert_object_export_type;
@@ -66,9 +69,10 @@ static char *ssconvert_import_id = NULL;
 static char *ssconvert_export_id = NULL;
 static char *ssconvert_export_options = NULL;
 static char *ssconvert_merge_target = NULL;
+static char **ssconvert_set_cells = NULL;
 static char **ssconvert_goal_seek = NULL;
 static char **ssconvert_tool_test = NULL;
-static const char *ssconvert_image_format = "svg";
+static const char *ssconvert_image_format = "auto";
 
 static const GOptionEntry ssconvert_options [] = {
 	{
@@ -152,6 +156,20 @@ static const GOptionEntry ssconvert_options [] = {
 		NULL
 	},
 
+	{
+		"list-image-formats", 0,
+		0, G_OPTION_ARG_NONE, &ssconvert_list_image_formats,
+		N_("List the available image formats"),
+		NULL
+	},
+
+	{
+		"set", 0,
+		0, G_OPTION_ARG_STRING_ARRAY, &ssconvert_set_cells,
+		N_("Change the contents of a cell before writing --set A12=2"),
+		NULL
+	},
+
 	{
 		"recalc", 0,
 		0, G_OPTION_ARG_NONE, &ssconvert_recalc,
@@ -278,6 +296,7 @@ handle_export_options (GOFileSaver *fs, Workbook *wb)
 		g_printerr ("ssconvert: %s\n", err
 			    ? err->message
 			    : _("Cannot parse export options."));
+		g_clear_error (&err);
 		return 1;
 	}
 
@@ -397,6 +416,32 @@ list_them (GList *them,
 	g_list_free (them_copy);
 }
 
+static void
+list_image_formats (void)
+{
+	GOImageFormat imfmt;
+	unsigned len = 0;
+
+	for (imfmt = (GOImageFormat)0; imfmt < GO_IMAGE_FORMAT_UNKNOWN; imfmt++) {
+		GOImageFormatInfo const *info = go_image_get_format_info (imfmt);
+		len = MAX (len, strlen (info->name));
+	}
+
+	g_printerr ("%-*s | %s\n", len,
+		    /* Translate these? */
+		    _("ID"),
+		    _("Description"));
+
+	for (imfmt = (GOImageFormat)0; imfmt < GO_IMAGE_FORMAT_UNKNOWN; imfmt++) {
+		GOImageFormatInfo const *info = go_image_get_format_info (imfmt);
+
+		g_printerr ("%-*s | %s\n", len,
+			    info->name,
+			    info->desc);
+	}
+}
+
+
 /*
  * Read the files we're going to merge and return a list of Workbooks.
  */
@@ -412,6 +457,7 @@ read_files_to_merge (const char *inputs[], GOFileOpener *fo,
 		WorkbookView *wbv =
 			workbook_view_new_from_uri (uri, fo, io_context,
 					      ssconvert_import_encoding);
+		// Do not apply any changes
 		g_free (uri);
 		inputs++;
 
@@ -588,7 +634,8 @@ merge (Workbook *wb, char const *inputs[],
 }
 
 static char *
-resolve_template (const char *template, Sheet *sheet, unsigned n)
+resolve_template (const char *template,
+		  Sheet *sheet, SheetObject *so, unsigned n)
 {
 	GString *s = g_string_new (NULL);
 	while (1) {
@@ -610,6 +657,16 @@ resolve_template (const char *template, Sheet *sheet, unsigned n)
 			case 's':
 				g_string_append (s, sheet->name_unquoted);
 				break;
+			case 'o': {
+				char *name = NULL;
+				if (so)
+					g_object_get (so, "name", &name, NULL);
+				if (name) {
+					g_string_append (s, name);
+					g_free (name);
+				}
+				break;
+			}
 			case '%':
 				g_string_append_c (s, '%');
 				break;
@@ -781,6 +838,122 @@ run_tool_test (const char *tool, char **argv, WorkbookView *wbv)
 #undef RANGE_LISTARG
 #undef SHEET_ARG
 
+static int
+by_anchor (gconstpointer a_, gconstpointer b_)
+{
+	SheetObject const *a = a_;
+	SheetObject const *b = b_;
+	double ca[4], cb[4];
+	unsigned ui;
+
+	// Caller ensures that sheets are the same
+	sheet_object_position_pts_get (a, ca);
+	sheet_object_position_pts_get (b, cb);
+
+	for (ui = 0; ui < G_N_ELEMENTS (ca); ui++) {
+		// We want T,L,B,R order
+		double d = ca[ui ^ 1] - cb[ui ^ 1];
+		if (d != 0)
+			return d < 0 ? -1 : +1;
+	}
+	return 0;
+}
+
+static const char *
+infer_image_format (const char *url)
+{
+	const char *ext;
+	GOImageFormat imfmt;
+
+	if (!url)
+		return NULL;
+
+	ext = gsf_extension_pointer (url);
+	for (imfmt = (GOImageFormat)0; imfmt < GO_IMAGE_FORMAT_UNKNOWN; imfmt++) {
+		GOImageFormatInfo const *info = go_image_get_format_info (imfmt);
+		if (info->ext && g_ascii_strcasecmp (ext, info->ext) == 0)
+			return info->name;
+	}
+	return NULL;
+}
+
+
+struct cb_image_export_options {
+	double resolution;
+};
+
+static gboolean
+cb_image_export_options (const char *key, const char *value,
+			 GError **err, gpointer user_)
+{
+	struct cb_image_export_options *user = user_;
+
+	if (strcmp (key, "resolution") == 0) {
+		user->resolution = atof (value);
+		if (user->resolution >= 1 && user->resolution <= 10000)
+			return FALSE;
+	}
+
+	if (err)
+		*err = g_error_new (go_error_invalid (), 0,
+				    _("Invalid export option \"%s=%s\" for image export"),
+				    key, value);
+
+	return TRUE;
+}
+
+static int
+export_objects_for_sheet (Sheet *sheet, const char *template,
+			  guint *file_idx)
+{
+
+	GSList *l, *objs = sheet_objects_get (sheet, NULL, G_TYPE_NONE);
+	int res = 0;
+
+	struct cb_image_export_options data;
+	data.resolution = 100;
+	if (ssconvert_export_options) {
+		GError *err = NULL;
+		gboolean fail;
+
+		fail = go_parse_key_value (ssconvert_export_options, &err,
+					   cb_image_export_options, &data);
+		if (fail) {
+			g_printerr ("ssconvert: %s\n", err
+				    ? err->message
+				    : _("Cannot parse export options."));
+			g_clear_error (&err);
+			return 1;
+		}
+	}
+
+	objs = g_slist_sort (objs, by_anchor);
+	for (l = objs; l; l = l->next) {
+		SheetObject *so = l->data;
+		char *tmpfile;
+		GError *err = NULL;
+
+		if (!g_type_is_a (G_TYPE_FROM_INSTANCE (so),
+				  ssconvert_object_export_type))
+			continue;
+
+		tmpfile = resolve_template (template, sheet, so, (*file_idx)++);
+		sheet_object_save_as_image (so, ssconvert_image_format,
+					    data.resolution,
+					    tmpfile, &err);
+
+		if (err) {
+			g_printerr ("Failed to write %s: %s\n", tmpfile, err->message);
+			g_error_free (err);
+			res = 1;
+		}
+
+		g_free (tmpfile);
+	}
+	g_slist_free (objs);
+
+	return res;
+}
 
 static int
 do_split_save (GOFileSaver *fs, WorkbookView *wbv,
@@ -839,33 +1012,10 @@ do_split_save (GOFileSaver *fs, WorkbookView *wbv,
 		}
 
 		if (ssconvert_object_export) {
-			GSList *l, *objs = sheet_objects_get (sheet, NULL, GNM_SO_GRAPH_TYPE);
-			double resolution = 100.0;
-			for (l = objs; l; l = l->next) {
-				SheetObject *so = l->data;
-				char *tmpfile;
-				GError *err = NULL;
-
-				if (!g_type_is_a (G_TYPE_FROM_INSTANCE (so),
-						  ssconvert_object_export_type))
-					continue;
-
-				tmpfile = resolve_template (template, sheet, file_idx++);
-				sheet_object_save_as_image (so, ssconvert_image_format, resolution,
-							    tmpfile, &err);
-
-				if (err) {
-					g_printerr ("Failed to write %s: %s\n", tmpfile, err->message);
-					g_error_free (err);
-					res = 1;
-					g_free (tmpfile);
-				}
-
-				g_free (tmpfile);
-			}
-			g_slist_free (objs);
+			if (export_objects_for_sheet (sheet, template, &file_idx))
+				res = 1;
 		} else {
-			char *tmpfile =	resolve_template (template, sheet, file_idx++);
+			char *tmpfile =	resolve_template (template, sheet, NULL, file_idx++);
 			res = !workbook_view_save_as (wbv, fs, tmpfile, cc);
 			g_free (tmpfile);
 		}
@@ -883,6 +1033,54 @@ do_split_save (GOFileSaver *fs, WorkbookView *wbv,
 	return res;
 }
 
+static int
+apply_updates (WorkbookView *wbv)
+{
+	Workbook *wb;
+	unsigned ui;
+	GnmParsePos pp;
+
+	if (!ssconvert_set_cells)
+		return 0;
+
+	wb = wb_view_get_workbook (wbv);
+	pp.wb = wb;
+	pp.sheet = workbook_sheet_by_index (wb, 0);
+	pp.eval.col = 0;
+	pp.eval.row = 0;
+
+	for (ui = 0; ssconvert_set_cells[ui]; ui++) {
+		const char *s = ssconvert_set_cells[ui];
+		const char *eq;
+		GnmRangeRef rr;
+		GnmRange r;
+		GnmParsePos pp2;
+		Sheet *start_sheet, *end_sheet;
+
+		eq = rangeref_parse (&rr, s, &pp, gnm_conventions_default);
+		if (!eq || *eq != '=')
+			goto error;
+
+		parse_pos_init_sheet (&pp2, wb_view_cur_sheet (wbv));
+		gnm_rangeref_normalize_pp (&rr, &pp2,
+					   &start_sheet, &end_sheet,
+					   &r);
+
+		pp2.eval.col = r.start.col;
+		pp2.eval.row = r.start.row;
+		sheet_range_set_text (&pp2, &r, eq + 1);
+		continue;
+
+	error:
+		g_printerr (_("Failed to set cell %s\n"), s);
+		return 1;
+	}
+
+	gnm_app_recalc ();
+
+	return 0;
+}
+
 static int
 convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	 GOCmdContext *cc)
@@ -902,6 +1100,11 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	if (ssconvert_object_export) {
 		if (ssconvert_export_id)
 			ssconvert_image_format = ssconvert_export_id;
+		if (g_str_equal (ssconvert_image_format, "auto")) {
+			ssconvert_image_format = infer_image_format (outfile);
+			if (!ssconvert_image_format)
+				ssconvert_image_format = DEFAULT_IMAGE_FORMAT;
+		}
 	} else if (ssconvert_export_id != NULL) {
 		fs = go_file_saver_for_id (ssconvert_export_id);
 		if (fs == NULL) {
@@ -968,6 +1171,10 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 		wbv = workbook_view_new_from_uri (infile, fo,
 						  io_context,
 						  ssconvert_import_encoding);
+		if (wbv && apply_updates (wbv)) {
+			res = 1;
+			goto out;
+		}
 	} else {
 		wbv = workbook_view_new (NULL);
 	}
@@ -1118,6 +1325,10 @@ clipboard_export (const char *inarg, char const *outarg, GOCmdContext *cc)
 	wbv = workbook_view_new_from_uri (infile, fo,
 					  io_context,
 					  ssconvert_import_encoding);
+	if (wbv && apply_updates (wbv)) {
+		res = 1;
+		goto out;
+	}
 
 	if (go_io_error_occurred (io_context)) {
 		go_io_error_display (io_context);
@@ -1248,6 +1459,8 @@ main (int argc, char const **argv)
 		list_them (go_get_file_openers (),
 			   (get_desc_f) &go_file_opener_get_id,
 			   (get_desc_f) &go_file_opener_get_description);
+	else if (ssconvert_list_image_formats)
+		list_image_formats ();
 	else if (ssconvert_clipboard)
 		if (argc == 3 && ssconvert_range)
 			res = clipboard_export (argv[1], argv[2], cc);
