@@ -169,9 +169,14 @@ workbook_dispose (GObject *wb_object)
 		Sheet *sheet = ptr->data;
 		GnmRange r;
 
+		sheet->being_destructed = TRUE;
+
 		sheet_destroy_contents (sheet);
 		range_init_full_sheet (&r, sheet);
+
 		sheet_style_set_range (sheet, &r, sheet_style_default (sheet));
+
+		sheet->being_destructed = FALSE;
 	}
 
 	/* Now remove the sheets themselves */
@@ -554,7 +559,7 @@ workbook_set_last_export_uri (Workbook *wb, const gchar *uri)
  * workbook_foreach_cell_in_range:
  * @pos: The position the range is relative to.
  * @cell_range: A value containing a range;
- * @flags: flags determining whichs cells to consider
+ * @flags: flags determining which cells to consider
  * @handler: (scope call): The operator to apply to each cell.
  * @closure: User data.
  *
